package Games::WavingHands::Parser;

use warnings;
use strict;

=head1 NAME

Games::WavingHands::Engine - The great new Games::WavingHands::Engine!

=head1 VERSION

Version 0.001

=cut

our $VERSION = '0.001';


=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use Games::WavingHands::Engine;

    my $foo = Games::WavingHands::Engine->new();
    ...

=head1 EXPORT

A list of functions that can be exported.  You can delete this section
if you don't export anything, such as for a purely object-oriented module.

=head1 FUNCTIONS

=head2 function1

=cut

sub function1 {
}

=head2 function2

=cut

sub function2 {
}

=head1 AUTHOR

Desmond Daignault, C<< <nawglan at cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-games-wavinghands-engine at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games::WavingHands>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Games::WavingHands


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games::WavingHands>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Games::WavingHands>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Games::WavingHands>

=item * Search CPAN

L<http://search.cpan.org/dist/Games::WavingHands>

=back


=head1 ACKNOWLEDGEMENTS


=head1 COPYRIGHT & LICENSE

Copyright 2014 Desmond Daignault, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut

1; # End of Games::WavingHands::Engine
